.. peewee documentation master file, created by
   sphinx-quickstart on Thu Nov 25 21:20:29 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

peewee
======

.. image:: peewee4-logo.png

Peewee is a simple and small ORM. It has few (but expressive) concepts, making
it easy to learn and intuitive to use.

* a small, expressive ORM
* flexible query-builder that exposes full power of SQL
* supports :ref:`sqlite, mysql, mariadb, postgresql <database>`.
* :ref:`asyncio support <pwasyncio>`
* tons of extensions
* use with :ref:`flask <flask>`, :ref:`fastapi <fastapi>`, :ref:`pydantic <pydantic>`
  and :ref:`more <framework-integration>`

Peewee's source code hosted on `GitHub <https://github.com/coleifer/peewee>`_.

New to peewee? These may help:

* :ref:`Quickstart <quickstart>`
* :ref:`Example twitter app <example>`
* :ref:`Using peewee interactively <interactive>`
* :ref:`Models and fields <models>`
* :ref:`Querying <querying>`
* :ref:`Relationships and joins <relationships>`
* :ref:`Extensive library of SQL / Peewee examples <query-library>`
* :ref:`Flask setup <flask>` or :ref:`FastAPI setup <fastapi>`

Contents:
---------

.. toctree::
   :maxdepth: 2

   peewee/installation
   peewee/quickstart
   peewee/example
   peewee/database
   peewee/models
   peewee/relationships
   peewee/querying
   peewee/writing
   peewee/query_operators
   peewee/transactions
   peewee/schema
   peewee/asyncio
   peewee/framework_integration
   peewee/interactive
   peewee/query_builder
   peewee/query_library
   peewee/api
   peewee/sqlite
   peewee/postgres
   peewee/mysql
   peewee/db_tools
   peewee/orm_utils
   peewee/recipes
   peewee/contributing

Note
----

If you find any bugs, odd behavior, or have an idea for a new feature please
don't hesitate to `open an issue <https://github.com/coleifer/peewee/issues?state=open>`_
on GitHub.

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
